==> estateplat-common-1.2.4-20190703.095229-190-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtJbqk.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    商品房买卖合同基本情况表(第二章)
 */
@Table(name = "fcjy_xjspf_mmht_jbqk")
public class FcjyXjspfMmhtJbqk implements Serializable {
    @Id
    private String qkid;//主键
    private String htid;//合同ID
    private String qlxz;//权利性质(权利性质字典表)
    private String zl;//坐落
    private String tdsyqzh;//土地使用权证号
    private Double tdsyqmj;//土地使用权面积（平方米）
    private String tdyt;//土地用途(地类代码字典表)
    private String tdsyzzrq;//土地使用权终止日期
    private String xmhzmc;//项目核准名称
    private String jsgcghxkzh;//建设工程规划许可证号
    private String jsgcsgxkzh;//建筑工程施工许可证号
    private String ysdjjg;//预售登记机构
    private String ysxkzh;//预售许可证号
    private String yszjjgjg;//预售资金监管机构
    private String yszjjgzhmc;//预售资金监管账户名称
    private String yszjjgzhzh;//预售资金监管账户账号
    private String ghyt;//规划用途(房屋用途字典表)
    private String jzjg;//建筑结构(建筑结构字典表)
    private String jzcs;//建筑层数
    private String dscs;//地上层数
    private String dxcs;//地下层数
    private String zh;//幢号
    private String dyh;//单元号
    private String szc;//所在层
    private String fjh;//房间号
    private String fwchjg;//房屋测绘机构
    private Double ycjzmj;//预测建筑面积（平方米）
    private Double yctnjzmj;//预测套内建筑面积（平方米）
    private Double ycftjzmj;//预测分摊建筑面积（平方米）
    private Double cg;//层高
    private Integer ytsl;//阳台数量
    private Integer fbsytsl;//封闭式阳台数量
    private Integer ffbsytsl;//非封闭式阳台数量
    private String dylx;//抵押类型
    private String dyr;//抵押人
    private String dyqr;//抵押权人
    private String djjg;//抵押登记机构
    private Date djrq;//抵押登记日
    private Date zwlxksqx;//债务履行开始期限
    private Date zwlxjsqx;//债务履行结束期限
    private String fwqlzkcn4;//房屋权利状况承诺4
    private String jflx;//给付利息(百分之)
    private String pcj;//赔偿金
    private String jzlx;//建筑类型
    private String dyqk;//抵押情况
    private String fwqlzkcn5;//房屋权利状况承诺5
    private String zffs;//支付方式
    private String tdsyqlx;//土地使用权类型
    private String zlqk;//租赁情况
    private String czqk;//出租情况
    private Date zlksqx;//租赁开始期限
    private Date zljsqx;//租赁结束期限
    private String fwsyr;//房屋收益人
    private String zlqt;//租赁其他
    private String xqmc;//小区名称
    private String ghytfj;//规划用途附记
    private String tdyt2;//土地用途2(地类代码字典表)

    public String getQkid() {
        return qkid;
    }

    public void setQkid(String qkid) {
        this.qkid = qkid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public Double getTdsyqmj() {
        return tdsyqmj;
    }

    public void setTdsyqmj(Double tdsyqmj) {
        this.tdsyqmj = tdsyqmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getTdsyzzrq() {
        return tdsyzzrq;
    }

    public void setTdsyzzrq(String tdsyzzrq) {
        this.tdsyzzrq = tdsyzzrq;
    }

    public String getXmhzmc() {
        return xmhzmc;
    }

    public void setXmhzmc(String xmhzmc) {
        this.xmhzmc = xmhzmc;
    }

    public String getJsgcghxkzh() {
        return jsgcghxkzh;
    }

    public void setJsgcghxkzh(String jsgcghxkzh) {
        this.jsgcghxkzh = jsgcghxkzh;
    }

    public String getJsgcsgxkzh() {
        return jsgcsgxkzh;
    }

    public void setJsgcsgxkzh(String jsgcsgxkzh) {
        this.jsgcsgxkzh = jsgcsgxkzh;
    }

    public String getYsdjjg() {
        return ysdjjg;
    }

    public void setYsdjjg(String ysdjjg) {
        this.ysdjjg = ysdjjg;
    }

    public String getYsxkzh() {
        return ysxkzh;
    }

    public void setYsxkzh(String ysxkzh) {
        this.ysxkzh = ysxkzh;
    }

    public String getYszjjgjg() {
        return yszjjgjg;
    }

    public void setYszjjgjg(String yszjjgjg) {
        this.yszjjgjg = yszjjgjg;
    }

    public String getYszjjgzhmc() {
        return yszjjgzhmc;
    }

    public void setYszjjgzhmc(String yszjjgzhmc) {
        this.yszjjgzhmc = yszjjgzhmc;
    }

    public String getYszjjgzhzh() {
        return yszjjgzhzh;
    }

    public void setYszjjgzhzh(String yszjjgzhzh) {
        this.yszjjgzhzh = yszjjgzhzh;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getJzjg() {
        return jzjg;
    }

    public void setJzjg(String jzjg) {
        this.jzjg = jzjg;
    }

    public String getJzcs() {
        return jzcs;
    }

    public void setJzcs(String jzcs) {
        this.jzcs = jzcs;
    }

    public String getDscs() {
        return dscs;
    }

    public void setDscs(String dscs) {
        this.dscs = dscs;
    }

    public String getDxcs() {
        return dxcs;
    }

    public void setDxcs(String dxcs) {
        this.dxcs = dxcs;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getFwchjg() {
        return fwchjg;
    }

    public void setFwchjg(String fwchjg) {
        this.fwchjg = fwchjg;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Double getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(Double yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public Double getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(Double ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public Integer getYtsl() {
        return ytsl;
    }

    public void setYtsl(Integer ytsl) {
        this.ytsl = ytsl;
    }

    public Integer getFbsytsl() {
        return fbsytsl;
    }

    public void setFbsytsl(Integer fbsytsl) {
        this.fbsytsl = fbsytsl;
    }

    public Integer getFfbsytsl() {
        return ffbsytsl;
    }

    public void setFfbsytsl(Integer ffbsytsl) {
        this.ffbsytsl = ffbsytsl;
    }

    public String getDylx() {
        return dylx;
    }

    public void setDylx(String dylx) {
        this.dylx = dylx;
    }

    public String getDyr() {
        return dyr;
    }

    public void setDyr(String dyr) {
        this.dyr = dyr;
    }

    public String getDyqr() {
        return dyqr;
    }

    public void setDyqr(String dyqr) {
        this.dyqr = dyqr;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public Date getDjrq() {
        return djrq;
    }

    public void setDjrq(Date djrq) {
        this.djrq = djrq;
    }

    public Date getZwlxksqx() {
        return zwlxksqx;
    }

    public void setZwlxksqx(Date zwlxksqx) {
        this.zwlxksqx = zwlxksqx;
    }

    public Date getZwlxjsqx() {
        return zwlxjsqx;
    }

    public void setZwlxjsqx(Date zwlxjsqx) {
        this.zwlxjsqx = zwlxjsqx;
    }

    public String getFwqlzkcn4() {
        return fwqlzkcn4;
    }

    public void setFwqlzkcn4(String fwqlzkcn4) {
        this.fwqlzkcn4 = fwqlzkcn4;
    }

    public String getJflx() {
        return jflx;
    }

    public void setJflx(String jflx) {
        this.jflx = jflx;
    }

    public String getPcj() {
        return pcj;
    }

    public void setPcj(String pcj) {
        this.pcj = pcj;
    }

    public String getJzlx() {
        return jzlx;
    }

    public void setJzlx(String jzlx) {
        this.jzlx = jzlx;
    }

    public String getDyqk() {
        return dyqk;
    }

    public void setDyqk(String dyqk) {
        this.dyqk = dyqk;
    }

    public String getFwqlzkcn5() {
        return fwqlzkcn5;
    }

    public void setFwqlzkcn5(String fwqlzkcn5) {
        this.fwqlzkcn5 = fwqlzkcn5;
    }

    public String getZffs() {
        return zffs;
    }

    public void setZffs(String zffs) {
        this.zffs = zffs;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getZlqk() {
        return zlqk;
    }

    public void setZlqk(String zlqk) {
        this.zlqk = zlqk;
    }

    public String getCzqk() {
        return czqk;
    }

    public void setCzqk(String czqk) {
        this.czqk = czqk;
    }

    public Date getZlksqx() {
        return zlksqx;
    }

    public void setZlksqx(Date zlksqx) {
        this.zlksqx = zlksqx;
    }

    public Date getZljsqx() {
        return zljsqx;
    }

    public void setZljsqx(Date zljsqx) {
        this.zljsqx = zljsqx;
    }

    public String getFwsyr() {
        return fwsyr;
    }

    public void setFwsyr(String fwsyr) {
        this.fwsyr = fwsyr;
    }

    public String getZlqt() {
        return zlqt;
    }

    public void setZlqt(String zlqt) {
        this.zlqt = zlqt;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getGhytfj() {
        return ghytfj;
    }

    public void setGhytfj(String ghytfj) {
        this.ghytfj = ghytfj;
    }

    public String getTdyt2() {
        return tdyt2;
    }

    public void setTdyt2(String tdyt2) {
        this.tdyt2 = tdyt2;
    }
}

==> estateplat-common-1.2.4-20190816.021013-219-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtJbqk.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    商品房买卖合同基本情况表(第二章)
 */
@Table(name = "fcjy_xjspf_mmht_jbqk")
public class FcjyXjspfMmhtJbqk implements Serializable {
    @Id
    private String qkid;//主键
    private String htid;//合同ID
    private String qlxz;//权利性质(权利性质字典表)
    private String zl;//坐落
    private String tdsyqzh;//土地使用权证号
    private Double tdsyqmj;//土地使用权面积（平方米）
    private String tdyt;//土地用途(地类代码字典表)
    private String tdsyzzrq;//土地使用权终止日期
    private String xmhzmc;//项目核准名称
    private String jsgcghxkzh;//建设工程规划许可证号
    private String jsgcsgxkzh;//建筑工程施工许可证号
    private String ysdjjg;//预售登记机构
    private String ysxkzh;//预售许可证号
    private String yszjjgjg;//预售资金监管机构
    private String yszjjgzhmc;//预售资金监管账户名称
    private String yszjjgzhzh;//预售资金监管账户账号
    private String ghyt;//规划用途(房屋用途字典表)
    private String jzjg;//建筑结构(建筑结构字典表)
    private String jzcs;//建筑层数
    private String dscs;//地上层数
    private String dxcs;//地下层数
    private String zh;//幢号
    private String dyh;//单元号
    private String szc;//所在层
    private String fjh;//房间号
    private String fwchjg;//房屋测绘机构
    private Double ycjzmj;//预测建筑面积（平方米）
    private Double yctnjzmj;//预测套内建筑面积（平方米）
    private Double ycftjzmj;//预测分摊建筑面积（平方米）
    private Double cg;//层高
    private Integer ytsl;//阳台数量
    private Integer fbsytsl;//封闭式阳台数量
    private Integer ffbsytsl;//非封闭式阳台数量
    private String dylx;//抵押类型
    private String dyr;//抵押人
    private String dyqr;//抵押权人
    private String djjg;//抵押登记机构
    private Date djrq;//抵押登记日
    private Date zwlxksqx;//债务履行开始期限
    private Date zwlxjsqx;//债务履行结束期限
    private String fwqlzkcn4;//房屋权利状况承诺4
    private String jflx;//给付利息(百分之)
    private String pcj;//赔偿金
    private String jzlx;//建筑类型
    private String dyqk;//抵押情况
    private String fwqlzkcn5;//房屋权利状况承诺5
    private String zffs;//支付方式
    private String tdsyqlx;//土地使用权类型
    private String zlqk;//租赁情况
    private String czqk;//出租情况
    private Date zlksqx;//租赁开始期限
    private Date zljsqx;//租赁结束期限
    private String fwsyr;//房屋收益人
    private String zlqt;//租赁其他
    private String xqmc;//小区名称
    private String ghytfj;//规划用途附记
    private String tdyt2;//土地用途2(地类代码字典表)
    private String dybajg;//抵押备案机构

    public String getQkid() {
        return qkid;
    }

    public void setQkid(String qkid) {
        this.qkid = qkid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public Double getTdsyqmj() {
        return tdsyqmj;
    }

    public void setTdsyqmj(Double tdsyqmj) {
        this.tdsyqmj = tdsyqmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getTdsyzzrq() {
        return tdsyzzrq;
    }

    public void setTdsyzzrq(String tdsyzzrq) {
        this.tdsyzzrq = tdsyzzrq;
    }

    public String getXmhzmc() {
        return xmhzmc;
    }

    public void setXmhzmc(String xmhzmc) {
        this.xmhzmc = xmhzmc;
    }

    public String getJsgcghxkzh() {
        return jsgcghxkzh;
    }

    public void setJsgcghxkzh(String jsgcghxkzh) {
        this.jsgcghxkzh = jsgcghxkzh;
    }

    public String getJsgcsgxkzh() {
        return jsgcsgxkzh;
    }

    public void setJsgcsgxkzh(String jsgcsgxkzh) {
        this.jsgcsgxkzh = jsgcsgxkzh;
    }

    public String getYsdjjg() {
        return ysdjjg;
    }

    public void setYsdjjg(String ysdjjg) {
        this.ysdjjg = ysdjjg;
    }

    public String getYsxkzh() {
        return ysxkzh;
    }

    public void setYsxkzh(String ysxkzh) {
        this.ysxkzh = ysxkzh;
    }

    public String getYszjjgjg() {
        return yszjjgjg;
    }

    public void setYszjjgjg(String yszjjgjg) {
        this.yszjjgjg = yszjjgjg;
    }

    public String getYszjjgzhmc() {
        return yszjjgzhmc;
    }

    public void setYszjjgzhmc(String yszjjgzhmc) {
        this.yszjjgzhmc = yszjjgzhmc;
    }

    public String getYszjjgzhzh() {
        return yszjjgzhzh;
    }

    public void setYszjjgzhzh(String yszjjgzhzh) {
        this.yszjjgzhzh = yszjjgzhzh;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getJzjg() {
        return jzjg;
    }

    public void setJzjg(String jzjg) {
        this.jzjg = jzjg;
    }

    public String getJzcs() {
        return jzcs;
    }

    public void setJzcs(String jzcs) {
        this.jzcs = jzcs;
    }

    public String getDscs() {
        return dscs;
    }

    public void setDscs(String dscs) {
        this.dscs = dscs;
    }

    public String getDxcs() {
        return dxcs;
    }

    public void setDxcs(String dxcs) {
        this.dxcs = dxcs;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getFwchjg() {
        return fwchjg;
    }

    public void setFwchjg(String fwchjg) {
        this.fwchjg = fwchjg;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Double getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(Double yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public Double getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(Double ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public Integer getYtsl() {
        return ytsl;
    }

    public void setYtsl(Integer ytsl) {
        this.ytsl = ytsl;
    }

    public Integer getFbsytsl() {
        return fbsytsl;
    }

    public void setFbsytsl(Integer fbsytsl) {
        this.fbsytsl = fbsytsl;
    }

    public Integer getFfbsytsl() {
        return ffbsytsl;
    }

    public void setFfbsytsl(Integer ffbsytsl) {
        this.ffbsytsl = ffbsytsl;
    }

    public String getDylx() {
        return dylx;
    }

    public void setDylx(String dylx) {
        this.dylx = dylx;
    }

    public String getDyr() {
        return dyr;
    }

    public void setDyr(String dyr) {
        this.dyr = dyr;
    }

    public String getDyqr() {
        return dyqr;
    }

    public void setDyqr(String dyqr) {
        this.dyqr = dyqr;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public Date getDjrq() {
        return djrq;
    }

    public void setDjrq(Date djrq) {
        this.djrq = djrq;
    }

    public Date getZwlxksqx() {
        return zwlxksqx;
    }

    public void setZwlxksqx(Date zwlxksqx) {
        this.zwlxksqx = zwlxksqx;
    }

    public Date getZwlxjsqx() {
        return zwlxjsqx;
    }

    public void setZwlxjsqx(Date zwlxjsqx) {
        this.zwlxjsqx = zwlxjsqx;
    }

    public String getFwqlzkcn4() {
        return fwqlzkcn4;
    }

    public void setFwqlzkcn4(String fwqlzkcn4) {
        this.fwqlzkcn4 = fwqlzkcn4;
    }

    public String getJflx() {
        return jflx;
    }

    public void setJflx(String jflx) {
        this.jflx = jflx;
    }

    public String getPcj() {
        return pcj;
    }

    public void setPcj(String pcj) {
        this.pcj = pcj;
    }

    public String getJzlx() {
        return jzlx;
    }

    public void setJzlx(String jzlx) {
        this.jzlx = jzlx;
    }

    public String getDyqk() {
        return dyqk;
    }

    public void setDyqk(String dyqk) {
        this.dyqk = dyqk;
    }

    public String getFwqlzkcn5() {
        return fwqlzkcn5;
    }

    public void setFwqlzkcn5(String fwqlzkcn5) {
        this.fwqlzkcn5 = fwqlzkcn5;
    }

    public String getZffs() {
        return zffs;
    }

    public void setZffs(String zffs) {
        this.zffs = zffs;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getZlqk() {
        return zlqk;
    }

    public void setZlqk(String zlqk) {
        this.zlqk = zlqk;
    }

    public String getCzqk() {
        return czqk;
    }

    public void setCzqk(String czqk) {
        this.czqk = czqk;
    }

    public Date getZlksqx() {
        return zlksqx;
    }

    public void setZlksqx(Date zlksqx) {
        this.zlksqx = zlksqx;
    }

    public Date getZljsqx() {
        return zljsqx;
    }

    public void setZljsqx(Date zljsqx) {
        this.zljsqx = zljsqx;
    }

    public String getFwsyr() {
        return fwsyr;
    }

    public void setFwsyr(String fwsyr) {
        this.fwsyr = fwsyr;
    }

    public String getZlqt() {
        return zlqt;
    }

    public void setZlqt(String zlqt) {
        this.zlqt = zlqt;
    }

    public String getXqmc() {
        return xqmc;
    }

    public void setXqmc(String xqmc) {
        this.xqmc = xqmc;
    }

    public String getGhytfj() {
        return ghytfj;
    }

    public void setGhytfj(String ghytfj) {
        this.ghytfj = ghytfj;
    }

    public String getTdyt2() {
        return tdyt2;
    }

    public void setTdyt2(String tdyt2) {
        this.tdyt2 = tdyt2;
    }

    public String getDybajg() {
        return dybajg;
    }

    public void setDybajg(String dybajg) {
        this.dybajg = dybajg;
    }
}
